@@ -22,11 +22,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 0.8.1
+Version 0.8.14
 
 =cut
 
-our $VERSION = '0.8.1';
+our $VERSION = '0.8.14';
 
 =head1 SYNOPSIS
 
@@ -996,6 +996,17 @@ sub get_user_details {
     return $self->_handle_security( $user, 'get', 'users' );
 } ## end sub get_user_details
 
+=head2 get_user_encrypted_password
+
+Get the encrypted password of the authenticated requestor
+
+=cut
+
+sub get_user_encrypted_password {
+    my $self = shift;
+    return $self->_handle_security( undef, 'get', 'encryptedPassword' );
+}
+
 =head2 create_or_replace_user( $user, %args )
 
 Creates a new user in Artifactory or replaces an existing user
@@ -1155,6 +1166,75 @@ sub security_configuration {
     return $self->get($url);
 } ## end sub security_configuration
 
+=head2 activate_master_key_encryption
+
+Creates a new master key and activates master key encryption
+
+=cut
+
+sub activate_master_key_encryption {
+    my $self = shift;
+    my $url  = $self->_api_url() . "/system/encrypt";
+    return $self->post($url);
+}
+
+=head2 deactivate_master_key_encryption
+
+Removes the current master key and deactivates master key encryption
+
+=cut
+
+sub deactivate_master_key_encryption {
+    my $self = shift;
+    my $url  = $self->_api_url() . "/system/decrypt";
+    return $self->post($url);
+}
+
+=head2 set_gpg_public_key
+
+Sets the public key that Artifactory provides to Debian clients to verify packages
+
+=cut
+
+sub set_gpg_public_key {
+    my $self = shift;
+    return $self->_handle_gpg_key( 'public', 'put' );
+}
+
+=head2 get_gpg_public_key
+
+Gets the public key that Artifactory provides to Debian clients to verify packages
+
+=cut
+
+sub get_gpg_public_key {
+    my $self = shift;
+    return $self->_handle_gpg_key( 'public', 'get' );
+}
+
+=head2 set_gpg_private_key
+
+Sets the private key that Artifactory will use to sign Debian packages
+
+=cut
+
+sub set_gpg_private_key {
+    my $self = shift;
+    return $self->_handle_gpg_key( 'private', 'put' );
+}
+
+=head2 set_gpg_pass_phrase( $passphrase )
+
+Sets the pass phrase required signing Debian packages using the private key
+
+=cut
+
+sub set_gpg_pass_phrase {
+    my ( $self, $pass ) = @_;
+    my %header = ( 'X-GPG-PASSPHRASE' => $pass );
+    return $self->_handle_gpg_key( 'passphrase', 'put', %header );
+}
+
 =head1 REPOSITORIES
 
 =cut
@@ -1240,13 +1320,8 @@ package currently hosted in the repository
 sub calculate_yum_repository_metadata {
     my ( $self, %args ) = @_;
     my $repository = $self->repository();
-    my $url =
-      (%args)
-      ? $self->_api_url() . "/yum/$repository?"
-      : $self->_api_url() . "/yum/$repository";
-    $url .= $self->_stringify_hash( '&', %args ) if (%args);
-    return $self->post($url);
-} ## end sub calculate_yum_repository_metadata
+    return $self->_handle_repository_reindex( "/yum/$repository", %args );
+}
 
 =head2 calculate_nuget_repository_metadata
 
@@ -1259,9 +1334,21 @@ internal nuspec file
 sub calculate_nuget_repository_metadata {
     my $self       = shift;
     my $repository = $self->repository();
-    my $url        = $self->_api_url() . "/nuget/$repository/reindex";
-    return $self->post($url);
-} ## end sub calculate_nuget_repository_metadata
+    return $self->_handle_repository_reindex("/nuget/$repository/reindex");
+}
+
+=head2 calculate_npm_repository_metadata
+
+Recalculates the npm search index for this repository (local/virtual). Please see the Npm integration documentation for
+more details.
+
+=cut
+
+sub calculate_npm_repository_metadata {
+    my $self       = shift;
+    my $repository = $self->repository();
+    return $self->_handle_repository_reindex("/npm/$repository/reindex");
+}
 
 =head2 calculate_maven_index( repos => [ 'repo1', 'repo2' ], force => 0/1 )
 
@@ -1290,6 +1377,19 @@ sub calculate_maven_metadata {
     return $self->post($url);
 } ## end sub calculate_maven_metadata
 
+=head2 calculate_debian_repository_metadata( async => 0/1 )
+
+Calculates/recalculates the Packages and Release metadata for this repository,based on the Debian packages in it.
+Calculation can be synchronous (the default) or asynchronous.
+
+=cut
+
+sub calculate_debian_repository_metadata {
+    my ( $self, %args ) = @_;
+    my $repository = $self->repository();
+    return $self->_handle_repository_reindex( "/deb/reindex/$repository", %args );
+}
+
 =head1 SYSTEM & CONFIGURATION
 
 =cut
@@ -1345,6 +1445,36 @@ sub save_general_configuration {
     );
 } ## end sub save_general_configuration
 
+=head2 license_information
+
+Retrieve information about the currently installed license
+
+=cut
+
+sub license_information {
+    my $self = shift;
+
+    my $url = $self->_api_url() . "/system/license";
+    return $self->get($url);
+}
+
+=head2 install_license( $licensekey )
+
+Install new license key or change the current one
+
+=cut
+
+sub install_license {
+    my ( $self, $key ) = @_;
+    my $url = $self->_api_url() . "/system/license";
+
+    return $self->post(
+        $url,
+        'Content-Type' => 'application/json',
+        content        => $self->_json->encode( { licenseKey => $key } )
+    );
+}
+
 =head2 version_and_addons_information
 
 Retrieve information about the current Artifactory version, revision, and
@@ -1721,6 +1851,22 @@ sub _handle_system_settings {
     return $self->get($url);
 } ## end sub _handle_system_settings
 
+sub _handle_gpg_key {
+    my ( $self, $type, $method, %args ) = @_;
+    my $url = $self->_api_url() . "/gpg/key/$type";
+    return $self->$method( $url, %args );
+}
+
+sub _handle_repository_reindex {
+    my ( $self, $endpoint, %args ) = @_;
+    my $url =
+      (%args)
+      ? $self->_api_url() . $endpoint . "?"
+      : $self->_api_url() . $endpoint;
+    $url .= $self->_stringify_hash( '&', %args ) if (%args);
+    return $self->post($url);
+}
+
 sub _merge_repo_and_path {
     my ( $self, $_path ) = @_;
 
@@ -1776,7 +1922,7 @@ L<http://search.cpan.org/dist/Artifactory-Client/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014, Yahoo! Inc.
+Copyright 2014-2015, Yahoo! Inc.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the the Artistic License (2.0). You may obtain a copy of the full
